### Abstract

This protocol describes how to replicate the analysis of survey data on child sexual abuse material (CSAM) users using the R Project for Statistical Computing (R).
We provide the survey responses as a CSV file.
With this protocol, you can open the CSV file using R and output the response tables and cross-comparisons.

### Introduction

The dataset includes answers to an anonymous online questionnaire, 'Help us to help you',  from May 5, 2021, to February 28, 2023.
We analysed responses from all people who answered the survey (N = 11,470).
We removed needless variables from the shared dataset and randomised the response ordering.

### Equipment

**Software requirements for Python and R calculations**

1. Command-line interface application (Terminal in Mac OS or Linux; or Command Prompt in Windows)
2. R version 4.0.2 or later (download from [https://cran.r-project.org/](https://cran.r-project.org/))
3. For easier use R Studio IDE can be installed [https://posit.co/download/rstudio-desktop/](https://posit.co/download/rstudio-desktop/)

**Hardware requirements for the calculations**

1. Most standard personal computers are suitable of executing the scripts included in this protocol.
2. For example, a standard CPU with 4 GB of RAM.

### Procedure

**Download the survey responses ● TIMING 1 min**

- Download the Supplementary Data, survey_data.csv.

**Perform the calculations ● TIMING 10 min**

The commands below output the response tables and cross-comparisons between the responses.

**Read in csv data**

```
data <- read.csv("/path/survey_data.csv")
```

**Frequency tables of variables analyzed in Figure 5, excluding missing answers. The code prints 1) name of the variable, 2) counts and 3) proportions**

```
colnames(data[1])
table(data[[1]])
table(data[[1]]) / sum(table(data[[1]])) * 100

colnames(data[2])
table(data[[2]])
table(data[[2]]) / sum(table(data[[2]])) * 100

colnames(data[5])
table(data[[5]])
table(data[[5]]) / sum(table(data[[5]])) * 100

colnames(data[6])
table(data[[6]])
table(data[[6]]) / sum(table(data[[6]])) * 100

colnames(data[7])
table(data[[7]])
table(data[[7]]) / sum(table(data[[7]])) * 100

colnames(data[12])
table(data[[12]])
table(data[[12]]) / sum(table(data[[12]])) * 100
```

**Crosstabulations in the supplementary file**

```
data$outcome_missing <- as.numeric(is.na(data[[12]]))
supplement <- subset(data, outcome_missing==0)

colnames(supplement[1])
table(supplement[[1]], supplement[[12]], useNA = "always")

colnames(supplement[3])
table(supplement[[3]], supplement[[12]], useNA = "always")

colnames(supplement[4])
table(supplement[[4]], supplement[[12]], useNA = "always")

colnames(supplement[5])
table(supplement[[5]], supplement[[12]], useNA = "always")

colnames(supplement[8])
table(supplement[[8]], supplement[[12]], useNA = "always")

colnames(supplement[9])
table(supplement[[9]], supplement[[12]], useNA = "always")

colnames(supplement[10])
table(supplement[[10]], supplement[[12]], useNA = "always")

colnames(supplement[11])
table(supplement[[11]], supplement[[12]], useNA = "always")
```

### Timing

A novice user can complete the Procedure described above and verify the results in less than 15 minutes.

